Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/arm/sunxi Apply RTL8211E "no-tx-delay" workaround t...



details:   https://anonhg.NetBSD.org/src/rev/f16d0f494d53
branches:  trunk
changeset: 829363:f16d0f494d53
user:      jmcneill <jmcneill%NetBSD.org@localhost>
date:      Sat Jan 27 14:17:45 2018 +0000

description:
Apply RTL8211E "no-tx-delay" workaround to NanoPi NEO Plus2 boards as well.

diffstat:

 sys/arch/arm/sunxi/sunxi_platform.c |  12 ++++++++----
 1 files changed, 8 insertions(+), 4 deletions(-)

diffs (33 lines):

diff -r 47b8b37a21a1 -r f16d0f494d53 sys/arch/arm/sunxi/sunxi_platform.c
--- a/sys/arch/arm/sunxi/sunxi_platform.c       Sat Jan 27 10:07:41 2018 +0000
+++ b/sys/arch/arm/sunxi/sunxi_platform.c       Sat Jan 27 14:17:45 2018 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: sunxi_platform.c,v 1.18 2017/12/23 12:50:55 jmcneill Exp $ */
+/* $NetBSD: sunxi_platform.c,v 1.19 2018/01/27 14:17:45 jmcneill Exp $ */
 
 /*-
  * Copyright (c) 2017 Jared McNeill <jmcneill%invisible.ca@localhost>
@@ -31,7 +31,7 @@
 #include "opt_fdt_arm.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sunxi_platform.c,v 1.18 2017/12/23 12:50:55 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sunxi_platform.c,v 1.19 2018/01/27 14:17:45 jmcneill Exp $");
 
 #include <sys/param.h>
 #include <sys/bus.h>
@@ -140,8 +140,12 @@
        prop_dictionary_t prop = device_properties(self);
 
        if (device_is_a(self, "rgephy")) {
-               /* Pine64+ gigabit ethernet workaround */
-               const char * compat[] = { "pine64,pine64-plus", NULL };
+               /* Pine64+ and NanoPi NEO Plus2 gigabit ethernet workaround */
+               const char * compat[] = {
+                       "pine64,pine64-plus",
+                       "friendlyarm,nanopi-neo-plus2",
+                       NULL
+               };
                if (of_match_compatible(OF_finddevice("/"), compat)) {
                        prop_dictionary_set_bool(prop, "no-rx-delay", true);
                }



Home | Main Index | Thread Index | Old Index